@@ -6,3 +6,7 @@ FEE = os.getenv('FEE', '20')
 GAS_LIMIT = os.getenv('GAS_LIMIT', '200000')
 CHAIN_ID = os.getenv('CHAIN_ID', 'evmos_9000-1')
 DENOM = os.getenv('DENOM', 'aphoton')
+
+# Types
+ETHSECP256K1 = 'ethsecp256k1'
+SECP256K1 = 'secp256k1'
